@@ -1,17 +1,16 @@
 ################################################################################
-# (C) COPYRIGHT 2000, Eric Busboom <eric@softwarestudio.org>
-#     http://www.softwarestudio.org
+# (C) COPYRIGHT 2000, Eric Busboom <eric@civicknowledge.com>
 #
-# This program is free software; you can redistribute it and/or modify
+# This library is free software; you can redistribute it and/or modify
 # it under the terms of either:
 #
 #   The LGPL as published by the Free Software Foundation, version
-#   2.1, available at: http://www.gnu.org/licenses/lgpl-2.1.txt
+#   2.1, available at: https://www.gnu.org/licenses/lgpl-2.1.txt
 #
 # Or:
 #
-#   The Mozilla Public License Version 1.0. You may obtain a copy of
-#   the License at http://www.mozilla.org/MPL/
+#   The Mozilla Public License Version 2.0. You may obtain a copy of
+#   the License at https://www.mozilla.org/MPL/
 ################################################################################
 
 sub read_values_file
@@ -100,11 +99,20 @@ sub read_properties_file
     my $enumConst     = $column[1];
     my $lic_value     = $column[2];
     my $default_value = $column[3];
+    my $flags         = $column[4];
+
+    my @flags;
+    if ($flags ne "") {
+      @flags = split(/;/, $flags);
+    } else {
+      @flags = ();
+    }
 
     $h{$property_name} = {
       lic_value     => $lic_value,
       kindEnum      => $enumConst,
-      default_value => $default_value
+      default_value => $default_value,
+      flags         => [@flags]
     };
   }
 
