@@ -37,7 +37,7 @@ public class testjni
 		starttime.setHour(18);
 		starttime.setMinute(0);
 		starttime.setSecond(0);
-		starttime.setIs_utc(true);
+		starttime.setZone("UTC");
 		System.out.println("done creating starttime");
 
 		ICalTimeType endtime = new ICalTimeType();
@@ -47,7 +47,7 @@ public class testjni
 		endtime.setHour(8);
 		endtime.setMinute(0);
 		endtime.setSecond(0);
-		endtime.setIs_utc(true);
+		endtime.setZone("UTC");
 		System.out.println("done creating endtime");
 
 
@@ -258,7 +258,7 @@ public class testjni
 		time_tma.setHour(2);
 		time_tma.setMinute(2);
 		time_tma.setSecond(2);
-		time_tma.setIs_utc(true);
+		time_tma.setZone("UTC");
 
 		ic.set_recurrenceid(time_tma);
 
@@ -299,7 +299,7 @@ public class testjni
                 duetime.setHour(18);
                 duetime.setMinute(0);
                 duetime.setSecond(0);
-                duetime.setIs_utc(true);
+                duetime.setZone("UTC");
                 System.out.println("done creating duetime");
 
                 statusProp.set_status(ICalProperty.ICalPropertyStatus.ICAL_STATUS_COMPLETED);
@@ -330,7 +330,7 @@ public class testjni
                 // AFTER the event or task start or due date, which is useless.
                 duration.setIs_neg(1);
 
-                // 2. Create a ICalTriggerType oject and set the duration on it.
+                // 2. Create a ICalTriggerType object and set the duration on it.
                 ICalTriggerType trigger = new ICalTriggerType();
                 trigger.setDuration(duration);
                 System.out.println("set trigger to duration object");
