@@ -149,10 +149,8 @@ static char *parser_get_next_char(char c, char *str, int qm)
     char *p = str;
     char next_char = *p;
     char prev_char = 0;
-    unsigned int cnt = 0;
 
-    while ((cnt < TMP_BUF_SIZE) && (next_char != '\0')) {
-        cnt++;
+    while (next_char != '\0') {
         if ((prev_char != '\0') && (prev_char != '\\')) {
             if (qm == 1 && next_char == '"') {
                 /* Encountered a quote, toggle quote mode */
@@ -176,15 +174,13 @@ static char *make_segment(char *start, char *end)
 {
     char *buf, *tmp;
     ptrdiff_t size = (ptrdiff_t)(end - start);
-    ptrdiff_t cnt = 0;
 
     buf = icalmemory_new_buffer((size_t)(size + 1));
     strncpy(buf, start, size);
     *(buf + size) = 0;
 
     tmp = (buf + size);
-    while ((cnt < size) && (tmp >= buf) && ((*tmp == '\0') || iswspace((wint_t)*tmp))) {
-        cnt++;
+    while ((tmp >= buf) && ((*tmp == '\0') || iswspace((wint_t)*tmp))) {
         *tmp = 0;
         tmp--;
     }
@@ -630,7 +626,6 @@ icalcomponent *icalparser_parse(icalparser *parser,
                                 icalparser_line_gen_func line_gen_func)
 {
     char *line;
-    unsigned int cnt = 0;
     icalcomponent *c = 0;
     icalcomponent *root = 0;
     icalerrorstate es = icalerror_get_error_state(ICAL_MALFORMEDDATA_ERROR);
@@ -641,7 +636,6 @@ icalcomponent *icalparser_parse(icalparser *parser,
     icalerror_set_error_state(ICAL_MALFORMEDDATA_ERROR, ICAL_ERROR_NONFATAL);
 
     do {
-        cnt++;
         line = icalparser_get_line(parser, line_gen_func);
 
         if ((c = icalparser_add_line(parser, line)) != 0) {
@@ -681,7 +675,7 @@ icalcomponent *icalparser_parse(icalparser *parser,
             icalmemory_free_buffer(line);
             cont = 1;
         }
-    } while (cont && cnt < TMP_BUF_SIZE);
+    } while (cont);
 
     icalerror_set_error_state(ICAL_MALFORMEDDATA_ERROR, es);
 
